Use the for geography to specify the level that you are querying data for.
build_for_geographies.RdUse the for geography to specify the level that you are querying data for.
Arguments
- for_geo
<chr> the geographical level the data will describe, e.g.
"tract"- ...
<
dynamic-dots> The specific items to search for, which will be all items if you leave them empty.